@@ -234,7 +234,7 @@ class Arc3(Arc):
         begin=0,
         end=0,
         is_trigo_direction=False,
-        label="",
+        prop_dict=None,
         init_dict=None,
         init_str=None,
     ):
@@ -259,14 +259,14 @@ class Arc3(Arc):
                 end = init_dict["end"]
             if "is_trigo_direction" in list(init_dict.keys()):
                 is_trigo_direction = init_dict["is_trigo_direction"]
-            if "label" in list(init_dict.keys()):
-                label = init_dict["label"]
+            if "prop_dict" in list(init_dict.keys()):
+                prop_dict = init_dict["prop_dict"]
         # Set the properties (value check and convertion are done in setter)
         self.begin = begin
         self.end = end
         self.is_trigo_direction = is_trigo_direction
         # Call Arc init
-        super(Arc3, self).__init__(label=label)
+        super(Arc3, self).__init__(prop_dict=prop_dict)
         # The class is frozen (in Arc init), for now it's impossible to
         # add new properties
 
