@@ -54,7 +54,7 @@ class DXFImport(FrozenClass):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
             for pyleecan type, -1 will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
+        - __init__ (init_dict = d) d must be a dictionary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
@@ -112,9 +112,11 @@ class DXFImport(FrozenClass):
             return False
         return True
 
-    def compare(self, other, name="self"):
+    def compare(self, other, name="self", ignore_list=None):
         """Compare two objects and return list of differences"""
 
+        if ignore_list is None:
+            ignore_list = list()
         if type(other) != type(self):
             return ["type(" + name + ")"]
         diff_list = list()
@@ -124,6 +126,8 @@ class DXFImport(FrozenClass):
             diff_list.append(name + ".surf_dict")
         if other._BC_list != self._BC_list:
             diff_list.append(name + ".BC_list")
+        # Filter ignore differences
+        diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
 
     def __sizeof__(self):
@@ -197,7 +201,7 @@ class DXFImport(FrozenClass):
     surf_dict = property(
         fget=_get_surf_dict,
         fset=_set_surf_dict,
-        doc=u"""Dictionnary to assign the surfaces: key=complex reference point coordinate, value=label of the surface
+        doc=u"""dictionary to assign the surfaces: key=complex reference point coordinate, value=label of the surface
 
         :Type: dict
         """,
