@@ -53,7 +53,7 @@ class ImportMatrixVal(ImportMatrix):
         """Constructor of the class. Can be use in three ways :
         - __init__ (arg1 = 1, arg3 = 5) every parameters have name and default values
             for pyleecan type, -1 will call the default constructor
-        - __init__ (init_dict = d) d must be a dictionnary with property names as keys
+        - __init__ (init_dict = d) d must be a dictionary with property names as keys
         - __init__ (init_str = s) s must be a string
         s is the file path to load
 
@@ -104,9 +104,11 @@ class ImportMatrixVal(ImportMatrix):
             return False
         return True
 
-    def compare(self, other, name="self"):
+    def compare(self, other, name="self", ignore_list=None):
         """Compare two objects and return list of differences"""
 
+        if ignore_list is None:
+            ignore_list = list()
         if type(other) != type(self):
             return ["type(" + name + ")"]
         diff_list = list()
@@ -115,6 +117,8 @@ class ImportMatrixVal(ImportMatrix):
         diff_list.extend(super(ImportMatrixVal, self).compare(other, name=name))
         if not array_equal(other.value, self.value):
             diff_list.append(name + ".value")
+        # Filter ignore differences
+        diff_list = list(filter(lambda x: x not in ignore_list, diff_list))
         return diff_list
 
     def __sizeof__(self):
