@@ -11,6 +11,18 @@ class Gen_PVentCirc(Ui_PVentCirc):
     def setupUi(self, PVentCirc):
         """Abstract class to update the widget according to the csv doc"""
         Ui_PVentCirc.setupUi(self, PVentCirc)
+        # Setup of in_Zh
+        txt = self.tr(u"""Number of Hole around the circumference""")
+        self.in_Zh.setWhatsThis(txt)
+        self.in_Zh.setToolTip(txt)
+
+        # Setup of si_Zh
+        self.si_Zh.setMinimum(0)
+        self.si_Zh.setMaximum(999999)
+        txt = self.tr(u"""Number of Hole around the circumference""")
+        self.si_Zh.setWhatsThis(txt)
+        self.si_Zh.setToolTip(txt)
+
         # Setup of in_Alpha0
         txt = self.tr(u"""Shift angle of the holes around circumference""")
         self.in_Alpha0.setWhatsThis(txt)
@@ -35,12 +47,12 @@ class Gen_PVentCirc(Ui_PVentCirc):
         self.lf_D0.setToolTip(txt)
 
         # Setup of in_H0
-        txt = self.tr(u"""Diameter of the hole centers""")
+        txt = self.tr(u"""Radius of the hole centers""")
         self.in_H0.setWhatsThis(txt)
         self.in_H0.setToolTip(txt)
 
         # Setup of lf_H0
         self.lf_H0.validator().setBottom(0)
-        txt = self.tr(u"""Diameter of the hole centers""")
+        txt = self.tr(u"""Radius of the hole centers""")
         self.lf_H0.setWhatsThis(txt)
         self.lf_H0.setToolTip(txt)
