@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from ....Functions.labels import WIND_LAB, BAR_LAB
 
 from ....Classes.LamSlotWind import LamSlotWind
 
@@ -31,7 +32,7 @@ def build_geometry(self, sym=1, alpha=0, delta=0, is_simplified=False):
 
     # Adapt the label
     for surf in surf_list:
-        if "Wind" in surf.label:
-            surf.label = surf.label.replace("Wind", "Bar")
+        if WIND_LAB in surf.label:
+            surf.label = surf.label.replace(WIND_LAB, BAR_LAB)
 
     return surf_list
