@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from numpy import abs, exp, pi, sum, array, linspace
+from ....Methods.Machine.Winding import WindingError
 
 
 def comp_winding_factor(self, Harmonics=[1]):
@@ -34,7 +35,7 @@ def comp_winding_factor(self, Harmonics=[1]):
     assert Zs > 0, "Zs must be >0"
     assert Zs % 1 == 0, "Zs must be an integer"
 
-    wind_mat = self.comp_connection_mat(Zs)
+    wind_mat = self.get_connection_mat(Zs)
     p = self.p
 
     # slot electrical angle
