@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from ....Classes.PointMat import PointMat
+from ....Classes.NodeMat import NodeMat
 from ....Classes.CellMat import CellMat
 from ....Classes.Interpolation import Interpolation
 from ....Classes.FPGNSeg import FPGNSeg
@@ -13,7 +13,7 @@ from itertools import combinations
 
 
 def interface(self, other_mesh):
-    """Define a MeshMat object corresponding to the exact intersection between two meshes (points must be in both meshes).
+    """Define a MeshMat object corresponding to the exact intersection between two meshes (nodes must be in both meshes).
 
     Parameters
     ----------
@@ -28,15 +28,17 @@ def interface(self, other_mesh):
 
     # Dynamic import
     new_mesh = self.copy()
-    # new_mesh.point = PointMat()
+    new_mesh._is_renum = True
+
+    # new_mesh.node = NodeMat()
     new_mesh.cell = dict()
 
     for key in self.cell:
 
         # Developer info: IDK if this code works with other than triangle cells. To be checked.
-        if self.cell[key].nb_pt_per_cell == 3:  # Triangle case
+        if self.cell[key].nb_node_per_cell == 3:  # Triangle case
 
-            new_mesh.cell["line"] = CellMat(nb_pt_per_cell=2)
+            new_mesh.cell["line"] = CellMat(nb_node_per_cell=2)
             interp = Interpolation()
             interp.gauss_point = FPGNSeg()
             interp.ref_cell = RefSegmentP1()
@@ -46,14 +48,14 @@ def interface(self, other_mesh):
             connect = self.cell[key].get_connectivity()
             connect2 = other_mesh.cell[key].get_connectivity()
 
-            points_tags = np.unique(connect)
-            other_points_tags = np.unique(connect2)
+            nodes_tags = np.unique(connect)
+            other_nodes_tags = np.unique(connect2)
 
-            # Find the points on the interface (they are in both in and out)
-            interface_points_tags = np.intersect1d(points_tags, other_points_tags)
-            nb_interf_points = len(interface_points_tags)
+            # Find the nodes on the interface (they are in both in and out)
+            interface_nodes_tags = np.intersect1d(nodes_tags, other_nodes_tags)
+            nb_interf_nodes = len(interface_nodes_tags)
 
-            comb = combinations(range(self.cell[key].nb_pt_per_cell), 2)
+            comb = combinations(range(self.cell[key].nb_node_per_cell), 2)
 
             for duo in list(comb):
                 col1i = np.mod(duo[0], 3)
@@ -64,16 +66,16 @@ def interface(self, other_mesh):
                 col1_bin = np.zeros(len(col1))
                 col2_bin = np.zeros(len(col1))
 
-                for pt in interface_points_tags:
-                    Icol1i = np.where(col1 == pt)[0]
-                    Icol2i = np.where(col2 == pt)[0]
+                for node in interface_nodes_tags:
+                    Icol1i = np.where(col1 == node)[0]
+                    Icol2i = np.where(col2 == node)[0]
                     col1_bin[Icol1i] = 1
                     col2_bin[Icol2i] = 1
 
                 # Position in vector where 2 nodes of the same element are on the interface (potential line element)
                 I_target = np.where(col1_bin + col2_bin == 2)[0]
 
-                comb2 = combinations(range(other_mesh.cell[key].nb_pt_per_cell), 2)
+                comb2 = combinations(range(other_mesh.cell[key].nb_node_per_cell), 2)
                 for duo2 in list(comb2):
                     col1j = np.mod(duo2[0], 3)
                     col2j = np.mod(duo2[1], 3)
@@ -83,9 +85,9 @@ def interface(self, other_mesh):
                     col12_bin = np.zeros(len(col12))
                     col22_bin = np.zeros(len(col12))
 
-                    for pt in interface_points_tags:
-                        Icol1i = np.where(col12 == pt)[0]
-                        Icol2i = np.where(col22 == pt)[0]
+                    for node in interface_nodes_tags:
+                        Icol1i = np.where(col12 == node)[0]
+                        Icol2i = np.where(col22 == node)[0]
                         col12_bin[Icol1i] = 1
                         col22_bin[Icol2i] = 1
 
@@ -103,25 +105,3 @@ def interface(self, other_mesh):
                             new_mesh.add_cell([e_tag1, e_tag2], "line")
 
     return new_mesh
-    # TODO : Extend the code to higher dimension (3 points triangles for tetrahedra interfaces ...)
-
-    # import matplotlib.pyplot as plt
-    # fig, ax = plt.subplots()
-    # x = mesh_group.point[:,0]
-    # y = mesh_group.point[:,1]
-    # ax.scatter(x, y)
-    # for ieleme in range(mesh_group.nb_elem):
-    #     x = mesh_group.point[interface_elem[ieleme,:],0]
-    #     y = mesh_group.point[interface_elem[ieleme,:],1]
-    #     ax.plot(x, y)
-    #
-    # fig, ax = plt.subplots()
-    # x = points_in[:, 0]
-    # y = points_in[:, 1]
-    # ax.scatter(x, y)
-    # x = points_out[:, 0]
-    # y = points_out[:, 1]
-    # ax.scatter(x, y)
-    # x = points_parent[interface_points_id, 0]
-    # y = points_parent[interface_points_id, 1]
-    # ax.scatter(x, y, marker='x')
