@@ -7,7 +7,7 @@ from ....Classes.MeshMat import MeshMat
 from ....definitions import config_dict
 
 COLOR_MAP = config_dict["PLOT"]["COLOR_DICT"]["COLOR_MAP"]
-
+FONT_FAMILY_PYVISTA = config_dict["PLOT"]["FONT_FAMILY_PYVISTA"]
 
 def plot_contour(
     self,
@@ -24,6 +24,7 @@ def plot_contour(
     save_path=None,
     itimefreq=0,
     is_show_fig=True,
+    win_title=None,
 ):
     """Plot the contour of a field on a mesh using pyvista plotter.
 
@@ -114,16 +115,16 @@ def plot_contour(
 
         # Configure plot
         if is_pyvistaqt:
-            p = pv.BackgroundPlotter()
+            p = pv.BackgroundPlotter(title=win_title)
             p.set_background("white")
         else:
             pv.set_plot_theme("document")
-            p = pv.Plotter(notebook=False)
+            p = pv.Plotter(notebook=False, title=win_title)
         sargs = dict(
             interactive=True,
             title_font_size=20,
             label_font_size=16,
-            font_family="arial",
+            font_family=FONT_FAMILY_PYVISTA,
             color="black",
         )
         p.add_mesh(
@@ -134,8 +135,26 @@ def plot_contour(
             clim=clim,
             scalar_bar_args=sargs,
         )
+        p.add_axes(color="k", x_color="#da3061", y_color="#0069a1", z_color="#bbcf1c")
         if self.dimension == 2:
+            # 2D view
             p.view_xy()
+        else:
+            # isometric view with z towards left
+            p.view_isometric()
+            p.camera_position = [
+                p.camera_position[0],
+                (
+                    p.camera_position[1][0],
+                    p.camera_position[1][2],
+                    p.camera_position[1][0],
+                ),
+                (
+                    p.camera_position[2][1],
+                    p.camera_position[2][2],
+                    p.camera_position[2][0],
+                ),
+            ]
         if save_path is None and is_show_fig:
             p.show()
         elif save_path is not None:
