@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
-from ....Methods.Slot.Slot.check import SlotCheckError
+from ....Methods.Slot.Slot import SlotCheckError
+from ....Methods.Slot.HoleM52 import *
 
 
 def check(self):
@@ -49,27 +50,3 @@ def check(self):
     W1 = self.comp_W1()
     if W1 <= 0:
         raise S52_W1CheckError("W1 is <=0, you must reduce W0 or W3")
-
-
-class S52_NoneError(SlotCheckError):
-    """Raised when a propery of HoleM52 is None"""
-
-    pass
-
-
-class S52_H12CheckError(SlotCheckError):
-    """ """
-
-    pass
-
-
-class S52_alphaCheckError(SlotCheckError):
-    """ """
-
-    pass
-
-
-class S52_W1CheckError(SlotCheckError):
-    """ """
-
-    pass
