@@ -1,9 +1,12 @@
-from ....Methods.Slot.Slot.check import SlotCheckError
+from ....Methods.Slot.Slot import SlotCheckError
 
 
 def check(self):
     """Check that the HoleUD is correctly defined"""
-
+    if self.surf_list is None:
+        self.surf_list = list()
+    if self.magnet_dict is None:
+        self.magnet_dict = dict()
     if len(self.surf_list) == 0:
         raise SlotCheckError("HoleUD must have at least one surface")
     for key in self.magnet_dict:
