@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from ....Classes.Arc2 import Arc2
+from ....Classes.Arc1 import Arc1
 from ....Classes.Segment import Segment
 
 
@@ -20,13 +20,18 @@ def build_geometry(self):
         A list of 2 Segment and 1 Arc
 
     """
-    (alpha_0, alpha_2) = self.comp_alphas()
-    [Z1, Z2, Z3, Z4] = self._comp_point_coordinate()
+
+    point_dict = self._comp_point_coordinate()
+    Z1 = point_dict["Z1"]
+    Z2 = point_dict["Z2"]
+    Z3 = point_dict["Z3"]
+    Z4 = point_dict["Z4"]
     Zc = 0
+
     # Creation of curve
     curve_list = list()
     curve_list.append(Segment(Z1, Z2))
-    curve_list.append(Arc2(Z2, Zc, alpha_2))
+    curve_list.append(Arc1(Z2, Z3, abs(Z2)))
     curve_list.append(Segment(Z3, Z4))
 
     return curve_list
