@@ -22,7 +22,7 @@ def comp_surface(self):
 
     S1 = self.H0 * self.W0
 
-    Swind = self.comp_surface_wind()
+    Swind = self.comp_surface_active()
 
     # The bottom is an arc
     alpha = self.comp_angle_opening()
