@@ -4,23 +4,20 @@ from numpy import exp, pi
 
 from ....Classes.PolarArc import PolarArc
 from ....Methods.Slot.VentilationPolar import *
+from ....Functions.labels import VENT_LAB
 
 
-def build_geometry(self, sym=1, alpha=0, delta=0, is_stator=True):
+def build_geometry(self, alpha=0, delta=0):
     """Compute the curve needed to plot the ventilations
 
     Parameters
     ----------
     self : VentilationPolar
         A VentilationPolar object
-    sym : int
-        Symetry to apply 2 = half the machine (Default value = 1 => full machine)
     alpha : float
         Angle for rotation (Default value = 0) [rad]
     delta : complex
         Complex for translation (Default value = 0)
-    is_stator : bool
-        True if ventilation is on the stator and 0 on the rotor (Default value = True)
 
     Returns
     -------
@@ -35,14 +32,11 @@ def build_geometry(self, sym=1, alpha=0, delta=0, is_stator=True):
         The parameter 'delta' must be a complex or float or int number
     """
 
-    if is_stator:
-        st = "Stator"
-    else:
-        st = "Rotor"
+    lam_label = self.parent.get_label()
+    RTS_id = "R" + str(self.parent.axial_vent.index(self)) + "-T0-S0"
+    vent_label = lam_label + "_" + VENT_LAB + "_" + RTS_id
 
     # checking if the param have good type
-    if not (isinstance(sym, int)) or sym <= 0:
-        raise PolarArcBuildGeometryError("The parameter 'sym' must be an integer > 0")
     if type(alpha) not in [int, float]:
         raise PolarArcBuildGeometryError(
             "The parameter 'alpha' must be an int or float"
@@ -53,21 +47,14 @@ def build_geometry(self, sym=1, alpha=0, delta=0, is_stator=True):
         )
 
     surf_list = list()
-    assert self.Zh % sym == 0
-    Zh = self.Zh // sym
-    # For every PolarArc
-    for ii in range(Zh):
-        Zc = (self.H0 + (self.D0 / 2)) * exp(
-            1j * (self.Alpha0 + ii * 2 * pi / self.Zh + (pi / self.Zh + alpha))
-        )
-        Zc += delta
-        surf_list.append(
-            PolarArc(
-                point_ref=Zc,
-                label="Ventilation_" + st + "_" + str(ii),
-                angle=self.W1,
-                height=self.D0,
-            )
+    Zc = (self.H0 + (self.D0 / 2)) * exp(1j * (self.Alpha0))
+    surf_list.append(
+        PolarArc(
+            point_ref=Zc,
+            label=vent_label,
+            angle=self.W1,
+            height=self.D0,
         )
+    )
 
     return surf_list
